@@ -25,7 +25,7 @@
 #include "tepl-utils.h"
 #include <string.h>
 
-/**
+/*
  * SECTION:utils
  * @title: TeplUtils
  * @short_description: Utility functions
@@ -292,105 +292,3 @@ _tepl_utils_get_fallback_basename_for_display (GFile *location)
 
 	return basename;
 }
-
-/* Deep copy of @strv. */
-gchar **
-_tepl_utils_strv_copy (const gchar * const *strv)
-{
-	guint length;
-	gchar **new_strv;
-	guint i;
-
-	if (strv == NULL)
-	{
-		return NULL;
-	}
-
-	length = g_strv_length ((gchar **)strv);
-
-	new_strv = g_malloc ((length + 1) * sizeof (gchar *));
-
-	for (i = 0; i < length; i++)
-	{
-		new_strv[i] = g_strdup (strv[i]);
-	}
-
-	new_strv[length] = NULL;
-
-	return new_strv;
-}
-
-static gint
-get_menu_item_position (GtkMenuShell *menu_shell,
-			GtkMenuItem  *item)
-{
-	GList *children;
-	GList *l;
-	gint pos;
-	gboolean found = FALSE;
-
-	children = gtk_container_get_children (GTK_CONTAINER (menu_shell));
-
-	for (l = children, pos = 0; l != NULL; l = l->next, pos++)
-	{
-		GtkMenuItem *cur_item = l->data;
-
-		if (cur_item == item)
-		{
-			found = TRUE;
-			break;
-		}
-	}
-
-	g_list_free (children);
-
-	return found ? pos : -1;
-}
-
-/**
- * tepl_utils_recent_chooser_menu_get_item_uri:
- * @menu: a #GtkRecentChooserMenu.
- * @item: a #GtkMenuItem.
- *
- * Gets the URI of @item. @item must be a child of @menu. @menu must be a
- * #GtkRecentChooserMenu.
- *
- * This function has been written because the value returned by
- * gtk_recent_chooser_get_current_uri() is not updated when #GtkMenuItem's of a
- * #GtkRecentChooserMenu are selected/deselected.
- *
- * Returns: the URI of @item. Free with g_free() when no longer needed.
- * Since: 2.0
- */
-gchar *
-tepl_utils_recent_chooser_menu_get_item_uri (GtkRecentChooserMenu *menu,
-					     GtkMenuItem          *item)
-{
-	gint pos;
-	gchar **all_uris;
-	gsize length;
-	gchar *item_uri = NULL;
-
-	g_return_val_if_fail (GTK_IS_RECENT_CHOOSER_MENU (menu), NULL);
-	g_return_val_if_fail (GTK_IS_MENU_ITEM (item), NULL);
-
-	{
-		GtkWidget *item_parent;
-
-		item_parent = gtk_widget_get_parent (GTK_WIDGET (item));
-		g_return_val_if_fail (item_parent == GTK_WIDGET (menu), NULL);
-	}
-
-	pos = get_menu_item_position (GTK_MENU_SHELL (menu), item);
-	g_return_val_if_fail (pos >= 0, NULL);
-
-	all_uris = gtk_recent_chooser_get_uris (GTK_RECENT_CHOOSER (menu), &length);
-
-	if ((gsize)pos < length)
-	{
-		item_uri = g_strdup (all_uris[pos]);
-	}
-
-	g_strfreev (all_uris);
-	return item_uri;
-}
